@@ -29,30 +29,6 @@ PCINFO = 15
 WAVE_ENDED = 16
 DONT_KNOW = 100
 
-WaveInstCategory = {
-    SKIP: "SKIP",
-    SMEM: "SMEM",
-    SALU: "SALU",
-    VMEM: "VMEM",
-    FLAT: "FLAT",
-    LDS: "LDS",
-    VALU: "VALU",
-    JUMP: "JUMP",
-    NEXT: "NEXT",
-    IMMED: "IMMED",
-    JUMP: "JUMP",
-    NEXT: "NEXT",
-    IMMED: "IMMED",
-    BRANCH: "BRANCH",
-    GETPC: "GETPC",
-    SETPC: "SETPC",
-    SWAPPC: "SWAPPC",
-    LANEIO: "LANEIO",
-    PCINFO: "PCINFO",
-    WAVE_ENDED: "WAVE_ENDED",
-    DONT_KNOW: "DONT_KNOW",
-}
-
 # Keeps track of register states for hipcc-generated assembly
 class RegisterWatchList:
     def __init__(self, labels, code, jump_map, insts):
@@ -249,13 +225,19 @@ class PCTranslator:
         pass
     def swappc(self, line, line_num, inst_index):
         try:
-            return self.getcode(self.insts[inst_index+1].cycles)[0][-3]
+            inst_pos = inst_index+1
+            while self.insts[inst_pos].type != PCINFO:
+                inst_pos += 1
+            return self.getcode(self.insts[inst_pos].cycles)[0][-3]
         except:
             print('SWAPPC warning: Could not find addr', hex(self.insts[inst_index+1].cycles), 'for', inst_index, line)
             return -1
     def setpc(self, line, inst_index):
         try:
-            return self.getcode(self.insts[inst_index+1].cycles)[0][-3]
+            inst_pos = inst_index+1
+            while self.insts[inst_pos].type != PCINFO:
+                inst_pos += 1
+            return self.getcode(self.insts[inst_pos].cycles)[0][-3]
         except:
             print('SETPC warning: Could not find addr', hex(self.insts[inst_index+1].cycles), 'for', inst_index, line)
             return -1
@@ -438,7 +420,7 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                 if "flat_" in as_line[0]:
                     inc_ordering = True
 
-                if not "_inv" in as_line[0] and not "_wb" in as_line[0]:
+                if not "buffer_" in as_line[0] or not ("_inv" in as_line[0] or "_wb" in as_line[0]):
                     if not bGFX9 and "store" in as_line[0]:
                         VSMEM_INST.append([reverse_map[line], num_inflight])
                         NUM_VSMEM += 1
@@ -455,8 +437,8 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                 vsmem_ordering = 1
                 FLAT_INST.append([reverse_map[line], num_inflight])
                 NUM_FLAT += 1
-            elif inst.type == IMMED and "s_waitcnt" in as_line[0]:
-                if "lgkmcnt" in as_line[0]:
+            elif inst.type == IMMED and "s_wait" in as_line[0]:
+                if "lgkmcnt" in as_line[0] or "dscnt" in as_line[0] or "kmcnt" in as_line[0]:
                     try:
                         wait_N = int(as_line[0].split("lgkmcnt(")[1].split(")")[0])
                     except:
@@ -478,7 +460,7 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                         NUM_FLAT = min(max(wait_N - NUM_SMEM, 0), NUM_FLAT)
                     num_inflight = NUM_FLAT + NUM_SMEM + NUM_VLMEM + NUM_VSMEM
 
-                if "vmcnt" in as_line[0]:
+                if "vmcnt" in as_line[0] or "loadcnt" in as_line[0]:
                     try:
                         wait_N = int(as_line[0].split("vmcnt(")[1].split(")")[0])
                     except:
@@ -500,7 +482,7 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                         NUM_FLAT = min(max(wait_N - NUM_VLMEM, 0), NUM_FLAT)
                     num_inflight = NUM_FLAT + NUM_SMEM + NUM_VLMEM + NUM_VSMEM
 
-                if "vscnt" in as_line[0] or (bGFX9 and "vmcnt" in as_line[0]):
+                if "vscnt" in as_line[0] or (bGFX9 and "vmcnt" in as_line[0]) or "storecnt" in as_line[0]:
                     try:
                         wait_N = int(as_line[0].split('vscnt(')[1].split(')')[0])
                     except:
@@ -539,8 +521,8 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                 insts[i] = insts[i + 1]
                 insts[i + 1] = temp
                 next = line
-            elif "s_waitcnt" in as_line[0] or "_load_" in as_line[0]:
-                if skipped_immed > 0 and "s_waitcnt" in as_line[0]:
+            elif "s_wait" in as_line[0] or "_load_" in as_line[0]:
+                if skipped_immed > 0 and "s_wait" in as_line[0]:
                     matched = True
                     skipped_immed -= 1
                 elif 'scratch_' not in as_line[0]:
@@ -553,7 +535,7 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
                 result.append(inst)
                 i += 1
                 num_failed_stitches = 0
-            elif not bGFX9 and inst.type == IMMED and line != next:
+            elif not bGFX9 and inst.type == IMMED and line != next and as_line[1] != SKIP:
                 skipped_immed += 1
                 inst.asmline = reverse_map[line]
                 result.append(inst)
@@ -571,7 +553,6 @@ def stitch(insts, raw_code, jumps, gfxv, bIsAuto, codeservice):
         print('Warning - Wave ended.')
     elif i < N:
         print('Warning - Stitching rate: '+str(i * 100 / N)+'% matched', i, ' of ', N)
-        print('Leftovers:', [WaveInstCategory[insts[i+k].type] for k in range(20) if i+k < len(insts)])
         try:
             print(line, code[line])
         except:
